#########
Test data
#########

Development
===========
- https://github.com/okfn/messytables/tree/master/horror
- https://github.com/frictionlessdata/tabulator-py/tree/main/data/special
- https://github.com/apache/arrow-testing/tree/master/data
- https://github.com/pandas-dev/pandas/tree/main/doc/data
- https://github.com/influxdata/influxdb2-sample-data
- https://github.com/konklone/json/tree/gh-pages/tests
- https://docs.databricks.com/dbfs/databricks-datasets.html
- https://github.com/databricks/tech-talks/blob/master/datasets/README.md
- https://www.kaggle.com/datasets
- https://github.com/earthobservations/testdata
- https://dd.weather.gc.ca/climate/observations/daily/csv/YT/
- https://srv.demo.crate.io/datasets/power_consumption.json
- https://srv.demo.crate.io/datasets/home_data_aa.csv
- https://srv.demo.crate.io/datasets/home_data_ab.csv


Production
==========
- https://www.govdata.de/
- https://www.destatis.de/EN/Service/OpenData/_node.html
- https://registry.opendata.aws/noaa-oar-hourly-gdp/
- https://www.freecodecamp.org/news/https-medium-freecodecamp-org-best-free-open-data-sources-anyone-can-use-a65b514b0f2d/
- https://learn.microsoft.com/en-us/azure/databricks/external-data/csv
- csv-to-lineprotocol: https://dganais.medium.com/getting-started-writing-data-to-influxdb-54ce99fdeb3e
- https://github.com/pandas-dev/pandas/issues/36688
- https://github.com/earthobservations/testdata
- https://www.kaggle.com/datasets/cesaber/spam-email-data-spamassassin-2002
